==> budget-rpc-0.1-sources.jar: com/chinayanghe/msp/budget/vo/checkbudget/out/CheckBudgetOutVo.java <==
/**
 * 2017 
 * 2017年5月9日  
 * 上午9:26:45
 * CheckBudgetOutVo.java
 * com.chinayanghe.msp.budget.vo.checkbudget.out
 * budget-rpc
 */
package com.chinayanghe.msp.budget.vo.checkbudget.out;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * @author yangshuo
 *
 */
public class CheckBudgetOutVo implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 5835560183842774547L;
	/**
	 * 品牌大类 
	 */
	private String   brandCategory;
	/**
	 * 渠道 
	 */
	private String   channel;
	/**
	 * 费用类型 
	 */
	private String   costType;
	/**
	 * 申请金额  金额必须大于0
	 */
	private BigDecimal   amount;
	
	/**
	 * 消息类型
	 */
	private String msgType;
	
	/**
	 * 消息内容
	 */
	private String msgBody;
	
	
	/**
	 * 预算项目地址ID
	 */
	private String budgetAddressCode;
	
	/**
	 * 预算可用金额
	 */
	private BigDecimal budgetCanUsedMoney;
    
    /*************以下是记录预算维度转换后的字段内容******************/
    /**
     * 预算年度
     */
    private Short budgetYear;

    /**
     *  预算品牌大类
     */
    private String budgetBrand;

    /**
     * 预算组织
     */
    private String budgetOrganization;

    /**
     * 预算对象类型编码
     */
    private String budgetObjType;

    /**
     * 预算类型编码
     */
    private String budgetType;

    /**
     * 预算经销商
     */
    private String budgetKunnr;

    /**
     *  预算费用类型
     */
    private String budgetCostType;

    /**
     * 是否专项预算
     */
    private String isSpecialCostType;

    /**
     * 预算渠道
     */
    private String budgetChannel;

    /**
     * 预算预留维度一
     */
    private String budgetExtend1;

    /**
     * 预算预留维度二
     */
    private String budgetExtend2;

    /**
     * 预算预留维度三
     */
    private String budgetExtend3;

    /**
     * 预算预留维度四
     */
    private String budgetExtend4;

    /**
     * 预算预留维度五
     */
    private String budgetExtend5;

	public String getBrandCategory() {
		return brandCategory;
	}

	public void setBrandCategory(String brandCategory) {
		this.brandCategory = brandCategory;
	}

	public String getChannel() {
		return channel;
	}

	public void setChannel(String channel) {
		this.channel = channel;
	}

	public String getCostType() {
		return costType;
	}

	public void setCostType(String costType) {
		this.costType = costType;
	}

	public BigDecimal getAmount() {
		return amount;
	}

	public void setAmount(BigDecimal amount) {
		this.amount = amount;
	}

	public String getMsgType() {
		return msgType;
	}

	public void setMsgType(String msgType) {
		this.msgType = msgType;
	}

	public String getMsgBody() {
		return msgBody;
	}

	public void setMsgBody(String msgBody) {
		this.msgBody = msgBody;
	}

	public String getBudgetAddressCode() {
		return budgetAddressCode;
	}

	public void setBudgetAddressCode(String budgetAddressCode) {
		this.budgetAddressCode = budgetAddressCode;
	}

	public BigDecimal getBudgetCanUsedMoney() {
		return budgetCanUsedMoney;
	}

	public void setBudgetCanUsedMoney(BigDecimal budgetCanUsedMoney) {
		this.budgetCanUsedMoney = budgetCanUsedMoney;
	}

	public Short getBudgetYear() {
		return budgetYear;
	}

	public void setBudgetYear(Short budgetYear) {
		this.budgetYear = budgetYear;
	}

	public String getBudgetBrand() {
		return budgetBrand;
	}

	public void setBudgetBrand(String budgetBrand) {
		this.budgetBrand = budgetBrand;
	}

	public String getBudgetOrganization() {
		return budgetOrganization;
	}

	public void setBudgetOrganization(String budgetOrganization) {
		this.budgetOrganization = budgetOrganization;
	}

	public String getBudgetObjType() {
		return budgetObjType;
	}

	public void setBudgetObjType(String budgetObjType) {
		this.budgetObjType = budgetObjType;
	}

	public String getBudgetType() {
		return budgetType;
	}

	public void setBudgetType(String budgetType) {
		this.budgetType = budgetType;
	}

	public String getBudgetKunnr() {
		return budgetKunnr;
	}

	public void setBudgetKunnr(String budgetKunnr) {
		this.budgetKunnr = budgetKunnr;
	}

	public String getBudgetCostType() {
		return budgetCostType;
	}

	public void setBudgetCostType(String budgetCostType) {
		this.budgetCostType = budgetCostType;
	}

	public String getIsSpecialCostType() {
		return isSpecialCostType;
	}

	public void setIsSpecialCostType(String isSpecialCostType) {
		this.isSpecialCostType = isSpecialCostType;
	}

	public String getBudgetChannel() {
		return budgetChannel;
	}

	public void setBudgetChannel(String budgetChannel) {
		this.budgetChannel = budgetChannel;
	}

	public String getBudgetExtend1() {
		return budgetExtend1;
	}

	public void setBudgetExtend1(String budgetExtend1) {
		this.budgetExtend1 = budgetExtend1;
	}

	public String getBudgetExtend2() {
		return budgetExtend2;
	}

	public void setBudgetExtend2(String budgetExtend2) {
		this.budgetExtend2 = budgetExtend2;
	}

	public String getBudgetExtend3() {
		return budgetExtend3;
	}

	public void setBudgetExtend3(String budgetExtend3) {
		this.budgetExtend3 = budgetExtend3;
	}

	public String getBudgetExtend4() {
		return budgetExtend4;
	}

	public void setBudgetExtend4(String budgetExtend4) {
		this.budgetExtend4 = budgetExtend4;
	}

	public String getBudgetExtend5() {
		return budgetExtend5;
	}

	public void setBudgetExtend5(String budgetExtend5) {
		this.budgetExtend5 = budgetExtend5;
	}
}

==> budget-rpc-0.3.0.6-sources.jar: com/chinayanghe/msp/budget/vo/checkbudget/out/CheckBudgetOutVo.java <==
/**
 * 2017 
 * 2017年5月9日  
 * 上午9:26:45
 * CheckBudgetOutVo.java
 * com.chinayanghe.msp.budget.vo.checkbudget.out
 * budget-rpc
 */
package com.chinayanghe.msp.budget.vo.checkbudget.out;

import java.io.Serializable;
import java.math.BigDecimal;

import com.chinayanghe.msp.budget.vo.out.ResponseItem;

/**
 * @author yangshuo
 *
 */
public class CheckBudgetOutVo extends ResponseItem implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = 5835560183842774547L;
	/**
	 * 品牌大类 
	 */
	private String   brandCategory;
	/**
	 * 渠道 
	 */
	private String   channel;
	/**
	 * 费用类型 
	 */
	private String   costType;
	/**
	 * 申请金额  金额必须大于0
	 */
	private BigDecimal   amount;
	
 
	
	
	/**
	 * 预算项目地址ID
	 */
	private String budgetAddressCode;
	
	/**
	 * 预算可用金额
	 */
	private BigDecimal budgetCanUsedMoney;
    
    /*************以下是记录预算维度转换后的字段内容******************/
    /**
     * 预算年度
     */
    private Short budgetYear;

    /**
     *  预算品牌大类
     */
    private String budgetBrand;

    /**
     * 预算组织
     */
    private String budgetOrganization;

    /**
     * 预算对象类型编码
     */
    private String budgetObjType;

    /**
     * 预算类型编码
     */
    private String budgetType;

    /**
     * 预算经销商
     */
    private String budgetKunnr;

    /**
     *  预算费用类型
     */
    private String budgetCostType;

    /**
     * 是否专项预算
     */
    private String isSpecialCostType;

    /**
     * 预算渠道
     */
    private String budgetChannel;

    /**
     * 预算预留维度一
     */
    private String budgetExtend1;

    /**
     * 预算预留维度二
     */
    private String budgetExtend2;

    /**
     * 预算预留维度三
     */
    private String budgetExtend3;

    /**
     * 预算预留维度四
     */
    private String budgetExtend4;

    /**
     * 预算预留维度五
     */
    private String budgetExtend5;

	public String getBrandCategory() {
		return brandCategory;
	}

	public void setBrandCategory(String brandCategory) {
		this.brandCategory = brandCategory;
	}

	public String getChannel() {
		return channel;
	}

	public void setChannel(String channel) {
		this.channel = channel;
	}

	public String getCostType() {
		return costType;
	}

	public void setCostType(String costType) {
		this.costType = costType;
	}

	public BigDecimal getAmount() {
		return amount;
	}

	public void setAmount(BigDecimal amount) {
		this.amount = amount;
	}

	 

	public String getBudgetAddressCode() {
		return budgetAddressCode;
	}

	public void setBudgetAddressCode(String budgetAddressCode) {
		this.budgetAddressCode = budgetAddressCode;
	}

	public BigDecimal getBudgetCanUsedMoney() {
		return budgetCanUsedMoney;
	}

	public void setBudgetCanUsedMoney(BigDecimal budgetCanUsedMoney) {
		this.budgetCanUsedMoney = budgetCanUsedMoney;
	}

	public Short getBudgetYear() {
		return budgetYear;
	}

	public void setBudgetYear(Short budgetYear) {
		this.budgetYear = budgetYear;
	}

	public String getBudgetBrand() {
		return budgetBrand;
	}

	public void setBudgetBrand(String budgetBrand) {
		this.budgetBrand = budgetBrand;
	}

	public String getBudgetOrganization() {
		return budgetOrganization;
	}

	public void setBudgetOrganization(String budgetOrganization) {
		this.budgetOrganization = budgetOrganization;
	}

	public String getBudgetObjType() {
		return budgetObjType;
	}

	public void setBudgetObjType(String budgetObjType) {
		this.budgetObjType = budgetObjType;
	}

	public String getBudgetType() {
		return budgetType;
	}

	public void setBudgetType(String budgetType) {
		this.budgetType = budgetType;
	}

	public String getBudgetKunnr() {
		return budgetKunnr;
	}

	public void setBudgetKunnr(String budgetKunnr) {
		this.budgetKunnr = budgetKunnr;
	}

	public String getBudgetCostType() {
		return budgetCostType;
	}

	public void setBudgetCostType(String budgetCostType) {
		this.budgetCostType = budgetCostType;
	}

	public String getIsSpecialCostType() {
		return isSpecialCostType;
	}

	public void setIsSpecialCostType(String isSpecialCostType) {
		this.isSpecialCostType = isSpecialCostType;
	}

	public String getBudgetChannel() {
		return budgetChannel;
	}

	public void setBudgetChannel(String budgetChannel) {
		this.budgetChannel = budgetChannel;
	}

	public String getBudgetExtend1() {
		return budgetExtend1;
	}

	public void setBudgetExtend1(String budgetExtend1) {
		this.budgetExtend1 = budgetExtend1;
	}

	public String getBudgetExtend2() {
		return budgetExtend2;
	}

	public void setBudgetExtend2(String budgetExtend2) {
		this.budgetExtend2 = budgetExtend2;
	}

	public String getBudgetExtend3() {
		return budgetExtend3;
	}

	public void setBudgetExtend3(String budgetExtend3) {
		this.budgetExtend3 = budgetExtend3;
	}

	public String getBudgetExtend4() {
		return budgetExtend4;
	}

	public void setBudgetExtend4(String budgetExtend4) {
		this.budgetExtend4 = budgetExtend4;
	}

	public String getBudgetExtend5() {
		return budgetExtend5;
	}

	public void setBudgetExtend5(String budgetExtend5) {
		this.budgetExtend5 = budgetExtend5;
	}
}
